// Detect Closest Edge
function closestEdge(x, y, w, h) {
    var topEdgeDist = distMetric(x, y, w / 2, 0);
    var bottomEdgeDist = distMetric(x, y, w / 2, h);
    var leftEdgeDist = distMetric(x, y, 0, h / 2);
    var rightEdgeDist = distMetric(x, y, w, h / 2);
    var min = Math.min(topEdgeDist, bottomEdgeDist, leftEdgeDist, rightEdgeDist);
    switch (min) {
        case leftEdgeDist:
            return 'left';
        case rightEdgeDist:
            return 'right';
        case topEdgeDist:
            return 'top';
        case bottomEdgeDist:
            return 'bottom';
    }
}

function getDirectionKey(e, $element) {
    var width = $element.outerWidth();
    var height = $element.outerHeight();
    var top = $element.offset().top;
    var left = $element.offset().left;

    var x = (e.pageX - left - (width / 2) * (width > height ? height / width : 1));
    var y = (e.pageY - top - (height / 2) * (height > width ? width / height : 1));

    var distanceIndex = Math.round(Math.atan2(y, x) / 1.57079633 + 5) % 4;

    switch(distanceIndex) {
        case 0:
            return 'top';
        case 1:
            return 'right';
        case 2:
            return 'bottom';
        case 3:
            return 'left';
    }
}

// Distance Formula
function distMetric(x, y, x2, y2) {
    var xDiff = x - x2;
    var yDiff = y - y2;
    return (xDiff * xDiff) + (yDiff * yDiff);
}

$('.edgeDetectionObserver').each(function(i) {
    var $container = $(this);
    var triggerHoverSelector = $container.data('igTriggerHoverSelector') || '.ce-textpic';
    var overlaySelector = $container.data('igOverlaySelector') || '.ce-bodytext';
    var onEnterFunctionName = $container.data('igOnEnterFunctionName');
    var onLeaveFunctionName = $container.data('igOnLeaveFunctionName');
    var $hoverElement = $container.find(triggerHoverSelector);
    var $overlay = $hoverElement.find(overlaySelector);

    $hoverElement.on('mouseenter', function(e) {
        var x = e.pageX - $hoverElement.offset().left;
        var y = e.pageY - $hoverElement.offset().top;
        var edge = closestEdge(x, y, $hoverElement.width(), $hoverElement.height());
        //var edge = getDirectionKey(e, $hoverElement);
        window[onEnterFunctionName]($overlay.get(0), edge);
    }).on('mouseleave', function(e) {
        var x = e.pageX - $hoverElement.offset().left;
        var y = e.pageY - $hoverElement.offset().top;
        var edge = closestEdge(x, y, $hoverElement.width(), $hoverElement.height());
        //var edge = getDirectionKey(e, $hoverElement);
        window[onLeaveFunctionName]($overlay.get(0), edge);
    });
});
